@@ -200,9 +200,13 @@ class MenuExtension_ownCloud(GObject.GObject, Nemo.MenuProvider):
                 break
         return (topLevelFolder, internalFile)
 
-    def get_file_items(self, window, files):
+    # The get_file_items method of Nemo.MenuProvider no longer takes
+    # the window argument. To keep supporting older versions of Nemo,
+    # we can use variadic arguments.
+    def get_file_items(self, *args):
         # Show the menu extension to share a file or folder
 
+        files = args[-1]
         # Get usable file paths from the uris
         all_internal_files = True
         for i, file_uri in enumerate(files):
